summaryrefslogtreecommitdiff
path: root/source4
diff options
context:
space:
mode:
authorMichael Adam <obnox@samba.org>2009-08-28 14:09:58 +0200
committerMichael Adam <obnox@samba.org>2009-08-28 14:25:40 +0200
commite3c7e9e81edf05f6946cac6f07a8bd8d6729adcb (patch)
treeb3cfcb2231c821bbed8498f57b7cbf8865efde01 /source4
parent9f1c162e3374250657e3f90c34df19031bb58c93 (diff)
downloadsamba-e3c7e9e81edf05f6946cac6f07a8bd8d6729adcb.tar.gz
samba-e3c7e9e81edf05f6946cac6f07a8bd8d6729adcb.tar.bz2
samba-e3c7e9e81edf05f6946cac6f07a8bd8d6729adcb.zip
s4-ldb: update dlinklist.h to match main copy (lib/util/dlinklist.h)
Michael
Diffstat (limited to 'source4')
-rw-r--r--source4/lib/ldb/include/dlinklist.h11
1 files changed, 5 insertions, 6 deletions
diff --git a/source4/lib/ldb/include/dlinklist.h b/source4/lib/ldb/include/dlinklist.h
index acab9fa043..62f885dd30 100644
--- a/source4/lib/ldb/include/dlinklist.h
+++ b/source4/lib/ldb/include/dlinklist.h
@@ -23,6 +23,7 @@
#ifndef _DLINKLIST_H
#define _DLINKLIST_H
+
/* hook into the front of the list */
#define DLIST_ADD(list, p) \
do { \
@@ -38,7 +39,6 @@ do { \
} while (0)
/* remove an element from a list - element doesn't have to be in list. */
-#ifndef DLIST_REMOVE
#define DLIST_REMOVE(list, p) \
do { \
if ((p) == (list)) { \
@@ -50,7 +50,6 @@ do { \
} \
if ((p) && ((p) != (list))) (p)->next = (p)->prev = NULL; \
} while (0)
-#endif
/* promote an element to the top of the list */
#define DLIST_PROMOTE(list, p) \
@@ -59,7 +58,7 @@ do { \
DLIST_ADD(list, p); \
} while (0)
/* hook into the end of the list - needs a tmp pointer */
#define DLIST_ADD_END(list, p, type) \
do { \
if (!(list)) { \
@@ -88,11 +87,11 @@ do { \
}\
} while (0)
/* demote an element to the end of the list, needs a tmp pointer */
#define DLIST_DEMOTE(list, p, tmp) \
do { \
DLIST_REMOVE(list, p); \
- DLIST_ADD_END(list, p, tmp); \
+ DLIST_ADD_END(list, p, type); \
} while (0)
/* concatenate two lists - putting all elements of the 2nd list at the
@@ -59,7 +58,7 @@ do { \
DLIST_ADD(list, p); \
} while (0)
-/* hook into the end of the list - needs a tmp pointer */
+/* hook into the end of the list - needs the entry type */
#define DLIST_ADD_END(list, p, type) \
do { \
@@ -88,11 +87,11 @@ do { \
}\
} while (0)
-/* demote an element to the end of the list, needs a tmp pointer */
-#define DLIST_DEMOTE(list, p, tmp) \
+/* demote an element to the end of the list, needs the entry type */
+#define DLIST_DEMOTE(list, p, type) \
do { \
DLIST_REMOVE(list, p); \